pub trait Credits {
// Required method
fn microcredits(&self) -> Result<u64>;
// Provided method
fn credits(&self) -> Result<f64> { ... }
}Expand description
A trait providing convenient methods for accessing the amount of Aleo present in a record
Required Methods
Sourcefn microcredits(&self) -> Result<u64>
fn microcredits(&self) -> Result<u64>
Get the amount of microcredits in the record if the record possesses Aleo credits
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".